@@ -1,8 +1,9 @@
-import requests
-import time
-import datetime
 import logging
 import json
+import time
+import datetime
+import requests
+
 
 logger = logging.getLogger(__name__)
 
@@ -11,6 +12,7 @@ class DiscordWebhook:
     """
     Webhook for Discord
     """
+
     def __init__(self, url, **kwargs):
         """
         Init Webhook for Discord
@@ -26,13 +28,13 @@ class DiscordWebhook:
         :keyword proxies: dict of proxies
         """
         self.url = url
-        self.content = kwargs.get('content')
-        self.username = kwargs.get('username')
-        self.avatar_url = kwargs.get('avatar_url')
-        self.tts = kwargs.get('tts', False)
-        self.files = kwargs.get('files', dict())
-        self.embeds = kwargs.get('embeds', [])
-        self.proxies = kwargs.get('proxies', None)
+        self.content = kwargs.get("content")
+        self.username = kwargs.get("username")
+        self.avatar_url = kwargs.get("avatar_url")
+        self.tts = kwargs.get("tts", False)
+        self.files = kwargs.get("files", dict())
+        self.embeds = kwargs.get("embeds", [])
+        self.proxies = kwargs.get("proxies", None)
 
     def add_file(self, file, filename):
         """
@@ -41,7 +43,7 @@ class DiscordWebhook:
         :param filename: filename
         :return:
         """
-        self.files['_{}'.format(filename)] = (filename, file)
+        self.files["_{}".format(filename)] = (filename, file)
 
     def add_embed(self, embed):
         """
@@ -72,6 +74,14 @@ class DiscordWebhook:
         """
         self.proxies = proxies
 
+    def set_content(self, content):
+        """
+        sets content
+        :param content: content string
+        :type content: string
+        """
+        self.content = content
+
     @property
     def json(self):
         """
@@ -85,11 +95,13 @@ class DiscordWebhook:
         for embed in embeds:
             self.add_embed(embed)
         for key, value in self.__dict__.items():
-            if value and key not in ['url', 'files', 'filename']:
+            if value and key not in ["url", "files", "filename"]:
                 data[key] = value
-        embeds_empty = all(not embed for embed in data["embeds"]) if 'embeds' in data else True
-        if embeds_empty and 'content' not in data and bool(self.files) is False:
-            logger.error('webhook message is empty! set content or embed data')
+        embeds_empty = (
+            all(not embed for embed in data["embeds"]) if "embeds" in data else True
+        )
+        if embeds_empty and "content" not in data and bool(self.files) is False:
+            logger.error("webhook message is empty! set content or embed data")
         return data
 
     def execute(self):
@@ -104,13 +116,23 @@ class DiscordWebhook:
             if bool(self.files) is False:
                 response = requests.post(url, json=self.json, proxies=self.proxies)
             else:
-                self.files['payload_json'] = (None, json.dumps(self.json))
+                self.files["payload_json"] = (None, json.dumps(self.json))
                 response = requests.post(url, files=self.files, proxies=self.proxies)
             if response.status_code in [200, 204]:
-                logger.debug("[{index}/{length}] Webhook executed".format(index=i, length=urls_len))
+                logger.debug(
+                    "[{index}/{length}] Webhook executed".format(
+                        index=i+1, length=urls_len
+                    )
+                )
             else:
-                logger.error('[{index}/{length}] Webhook status code {status_code}: {content}'.format(
-                    index=i, length=urls_len, status_code=response.status_code, content=response.content.decode("utf-8")))
+                logger.error(
+                    "[{index}/{length}] Webhook status code {status_code}: {content}".format(
+                        index=i+1,
+                        length=urls_len,
+                        status_code=response.status_code,
+                        content=response.content.decode("utf-8"),
+                    )
+                )
             responses.append(response)
         return responses[0] if len(responses) == 1 else responses
 
@@ -119,6 +141,7 @@ class DiscordEmbed:
     """
     Discord Embed
     """
+
     def __init__(self, **kwargs):
         """
         Init Discord Embed
@@ -135,18 +158,18 @@ class DiscordEmbed:
         :keyword author: author information
         :keyword fields: fields information
         """
-        self.title = kwargs.get('title')
-        self.description = kwargs.get('description')
-        self.url = kwargs.get('url')
-        self.timestamp = kwargs.get('timestamp')
-        self.color = kwargs.get('color')
-        self.footer = kwargs.get('footer')
-        self.image = kwargs.get('image')
-        self.thumbnail = kwargs.get('thumbnail')
-        self.video = kwargs.get('video')
-        self.provider = kwargs.get('provider')
-        self.author = kwargs.get('author')
-        self.fields = kwargs.get('fields', [])
+        self.title = kwargs.get("title")
+        self.description = kwargs.get("description")
+        self.url = kwargs.get("url")
+        self.timestamp = kwargs.get("timestamp")
+        self.color = kwargs.get("color")
+        self.footer = kwargs.get("footer")
+        self.image = kwargs.get("image")
+        self.thumbnail = kwargs.get("thumbnail")
+        self.video = kwargs.get("video")
+        self.provider = kwargs.get("provider")
+        self.author = kwargs.get("author")
+        self.fields = kwargs.get("fields", [])
 
     def set_title(self, title):
         """
@@ -193,9 +216,9 @@ class DiscordEmbed:
         :keyword proxy_icon_url: a proxied url of footer icon
         """
         self.footer = {
-            'text': kwargs.get('text'),
-            'icon_url': kwargs.get('icon_url'),
-            'proxy_icon_url': kwargs.get('proxy_icon_url')
+            "text": kwargs.get("text"),
+            "icon_url": kwargs.get("icon_url"),
+            "proxy_icon_url": kwargs.get("proxy_icon_url"),
         }
 
     def set_image(self, **kwargs):
@@ -207,10 +230,10 @@ class DiscordEmbed:
         :keyword width: width of image
         """
         self.image = {
-            'url': kwargs.get('url'),
-            'proxy_url': kwargs.get('proxy_url'),
-            'height': kwargs.get('height'),
-            'width': kwargs.get('width'),
+            "url": kwargs.get("url"),
+            "proxy_url": kwargs.get("proxy_url"),
+            "height": kwargs.get("height"),
+            "width": kwargs.get("width"),
         }
 
     def set_thumbnail(self, **kwargs):
@@ -222,10 +245,10 @@ class DiscordEmbed:
         :keyword width: width of thumbnail
         """
         self.thumbnail = {
-            'url': kwargs.get('url'),
-            'proxy_url': kwargs.get('proxy_url'),
-            'height': kwargs.get('height'),
-            'width': kwargs.get('width'),
+            "url": kwargs.get("url"),
+            "proxy_url": kwargs.get("proxy_url"),
+            "height": kwargs.get("height"),
+            "width": kwargs.get("width"),
         }
 
     def set_video(self, **kwargs):
@@ -236,9 +259,9 @@ class DiscordEmbed:
         :keyword width: width of video
         """
         self.video = {
-            'url': kwargs.get('url'),
-            'height': kwargs.get('height'),
-            'width': kwargs.get('width'),
+            "url": kwargs.get("url"),
+            "height": kwargs.get("height"),
+            "width": kwargs.get("width"),
         }
 
     def set_provider(self, **kwargs):
@@ -248,8 +271,8 @@ class DiscordEmbed:
         :keyword url: url of provider
         """
         self.provider = {
-            'name': kwargs.get('name'),
-            'url': kwargs.get('url'),
+            "name": kwargs.get("name"),
+            "url": kwargs.get("url"),
         }
 
     def set_author(self, **kwargs):
@@ -261,10 +284,10 @@ class DiscordEmbed:
         :keyword proxy_icon_url: a proxied url of author icon
         """
         self.author = {
-            'name': kwargs.get('name'),
-            'url': kwargs.get('url'),
-            'icon_url': kwargs.get('icon_url'),
-            'proxy_icon_url': kwargs.get('proxy_icon_url'),
+            "name": kwargs.get("name"),
+            "url": kwargs.get("url"),
+            "icon_url": kwargs.get("icon_url"),
+            "proxy_icon_url": kwargs.get("proxy_icon_url"),
         }
 
     def add_embed_field(self, **kwargs):
@@ -274,11 +297,13 @@ class DiscordEmbed:
         :keyword value: value of the field
         :keyword inline: (optional) whether or not this field should display inline
         """
-        self.fields.append({
-            'name': kwargs.get('name'),
-            'value': kwargs.get('value'),
-            'inline': kwargs.get('inline', True)
-        })
+        self.fields.append(
+            {
+                "name": kwargs.get("name"),
+                "value": kwargs.get("value"),
+                "inline": kwargs.get("inline", True),
+            }
+        )
 
     def del_embed_field(self, index):
         """
